Available backends
==================

Local watcher
-------------
.. automodule:: pytroll_watchers.local_watcher
   :members:

Minio bucket notification watcher
---------------------------------
.. automodule:: pytroll_watchers.minio_notification_watcher
   :members:

Copernicus dataspace watcher
----------------------------
.. automodule:: pytroll_watchers.dataspace_watcher
   :members:

EUMETSAT datastore watcher
--------------------------
.. automodule:: pytroll_watchers.datastore_watcher
   :members:

DHuS watcher
------------
.. automodule:: pytroll_watchers.dhus_watcher
   :members:
